Compute Consensus Ranking
# S3 method for BayesMallows
compute_consensus(
model_fit,
type = "CP",
burnin = model_fit$burnin,
parameter = "rho",
assessors = 1L,
...
)Object of type BayesMallows returned from
compute_mallows.
Character string specifying which consensus to compute. Either
"CP" or "MAP". Defaults to "CP".
A numeric value specifying the number of iterations to discard
as burn-in. Defaults to model_fit$burnin, and must be provided if
model_fit$burnin does not exist. See
assess_convergence.
Character string defining the parameter for which to compute
the consensus. Defaults to "rho". Available options are "rho"
and "Rtilde", with the latter giving consensus rankings for
augmented ranks.
When parameter = "rho", this integer vector is used
to define the assessors for which to compute the augmented ranking.
Other arguments passed on to other methods. Currently not used.
Defaults to 1L, which yields augmented rankings for assessor 1.
Other posterior quantities:
assign_cluster(),
compute_consensus.SMCMallows(),
compute_consensus(),
compute_posterior_intervals.BayesMallows(),
compute_posterior_intervals.SMCMallows(),
compute_posterior_intervals(),
heat_plot(),
plot.BayesMallows(),
plot.SMCMallows(),
plot_elbow(),
plot_top_k(),
predict_top_k(),
print.BayesMallowsMixtures(),
print.BayesMallows()